
// Render settings (right-click on a line below):
//+w1280 +h640 +a0.3 +am2 +bm2 +bs8 +wt6

//=================================================================================
// VERSION
//=================================================================================
#version 3.7;

//=================================================================================
// DEFAULTS AND INCLUDES
//=================================================================================
#default {pigment {rgb <1,0,0>}}

#include "colors.inc"
#include "rand.inc"

//=================================================================================
// SCENE SWITCHES
//=================================================================================
#declare PoF            = on; //Norbert Kern's Position Finder
#declare SeeScreen      = off;	// Gilles Tran's Visibility Test
#declare Rad            = on;

#declare AspectRatio    = image_width/image_height;
#declare CamZoom        = 1.4;  //change to set the visibility area
#declare CamSky         = <0, 1, 0>;
#declare CamAng         = 70;	//39
#declare CamLoc         = <-2000.0, 100, -2700.0>;
#declare CamLookAt      = <-2000.0, 5.0,  0.0>;

#declare HF_scale       = <8000, 1000, 8000>;

//=================================================================================
// GLOBAL SETTINGS
//=================================================================================
global_settings {
  assumed_gamma 1.0
  max_trace_level 5			//default [5]
  #if (Rad)
  radiosity {
    pretrace_start 0.08           // start pretrace at this size
    pretrace_end   0.004           // end pretrace at this size
    count 100, 1000                      // higher -> higher quality (1..1600) [35]
    nearest_count 10, 5               // higher -> higher quality (1..10) [5]
    error_bound 1               // higher -> smoother, less accurate [1.8]
    recursion_limit 2             // how much interreflections are calculated (1..5+) [3]
    low_error_factor .3           // reduce error_bound during last pretrace step
    gray_threshold 0.0            // increase for weakening colors (0..1) [0]
    minimum_reuse 0.015           // reuse of old radiosity samples [0.015]
    maximum_reuse 0.1							// new parameter 3.7 [0.2]
    brightness 1                  // brightness of radiosity effects (0..1) [1]

    adc_bailout 0.01/2
    normal off                   // take surface normals into account [off]
    media off                    // take media into account [off]
    always_sample off           // turn sampling in final trace off [on]
    //max_sample 1.0              // maximum brightness of samples
  }
  #end
  //noise_generator 2
}

//====================================================================================
// CAMERA AND LIGHT
//====================================================================================
#include "GT_VisibilityTest.mcr"

camera {
  location  CamLoc
  look_at   CamLookAt
  angle     CamAng
  sky       CamSky  
  up        CamSky
  direction z*CamZoom
  right     x*AspectRatio
}

light_source {
  <0, 0, 0>
  color rgb 1 
  translate <5, 4, 5>*10000
}

//====================================================================================
// SKY
//====================================================================================
sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}

//====================================================================================
// LANDSCAPE 
//====================================================================================
#declare Landscape =
height_field {
    function 500,500 {pattern {bozo scale 0.08}}
    smooth
    translate <-0.5, 0, -0.5>
    scale HF_scale
    translate -HF_scale.y*y
    texture {
      pigment {
        average
        pigment_map {
          [1.0 rgb <0.5, 1, 0.3>]
          [0.6 gradient x frequency 8
               color_map {
                 [0.07 rgb -0.3]
                 [0.07 rgb <0.7, 1, 0.7>]
               }
             ]
          [0.6 gradient z frequency 8
               color_map {
                 [0.07 rgb -0.3]
                 [0.07 rgb <0.7, 1, 0.7>]
               }
             ]
        }
      }
      finish {ambient 0 diffuse 0.5}
    }
    scale <1, 0.5, 1>
  }

Landscape

//====================================================================================
// TEST ROD
//====================================================================================
//Rod at position given by:
//#declare screen_x_position = 260; // screen percentages X 1000  (0 to 1000)
//#declare screen_y_position = 850; // ditto
cylinder {<0,0,0>, <0,100,0>,5 pigment {rgb <1,1,0>}
  translate <-2426.313, -269.700, -1300.118>
}

//on the screen, this puts the rod at:
//#declare screen_x_position = 285; // screen percentages X 1000  (0 to 1000)
//#declare screen_y_position = 828; // ditto

//====================================================================================
// POSITION FINDER 
//====================================================================================
#if (PoF)
#declare Standalone = false;
#debug "\nPosition Finder started...\n"

#include "KW_Position Finder.pov"

// definitions (for test scene below) _____________________________________
#declare screen_x_position = 285; // screen percentages X 1000  (0 to 1000)
#declare screen_y_position = 828; // ditto
#declare SURFACE           = object {Landscape};

#declare cam_loc = CamLoc;
#declare lookat  = CamLookAt;
#declare cam_ang = CamAng;

// The macro call
pos_finder (SURFACE, cam_loc, lookat, cam_ang, screen_x_position, screen_y_position, 1.0)

#end


